# fastomit

[![PyPI - Version](https://img.shields.io/pypi/v/fastomit.svg)](https://pypi.org/project/fastomit)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/fastomit.svg)](https://pypi.org/project/fastomit)

-----

**Table of Contents**

- [Installation](#installation)
- [License](#license)

## Installation

```console
pip install fastomit
```

## License

`fastomit` is distributed under the terms of the [MIT](https://spdx.org/licenses/MIT.html) license.
